ConfigFile

Struct ConfigFile 

pub struct ConfigFile {
Show 19 fields pub settings: Settings, pub endpoints: Vec<EndpointConfig>, pub disabled_endpoints: DisabledEndpoints, pub proxy: Option<ProxyFileConfig>, pub etherscan_api_key: Option<SecretString>, pub tenderly: Option<TenderlyConfig>, pub alchemy: Option<AlchemyConfig>, pub coingecko: Option<GeckoConfig>, pub defillama: Option<LlamaConfig>, pub moralis: Option<MoralisConfig>, pub dune: Option<DuneConfig>, pub dune_sim: Option<DuneSimConfig>, pub chainlink: Option<ChainlinkConfig>, pub zerox: Option<ZeroxConfig>, pub oneinch: Option<OneInchConfig>, pub enso: Option<EnsoConfig>, pub thegraph: Option<TheGraphConfig>, pub solodit: Option<SoloditConfig>, pub debug_rpc_urls: Vec<String>,
}
Configuration file structure

Fields

settings: Settings

Global settings

endpoints: Vec<EndpointConfig>

Custom endpoints

disabled_endpoints: DisabledEndpoints

Disabled endpoints

proxy: Option<ProxyFileConfig>

Proxy configuration

etherscan_api_key: Option<SecretString>

Etherscan API key

tenderly: Option<TenderlyConfig>

Tenderly configuration

alchemy: Option<AlchemyConfig>

Alchemy configuration

coingecko: Option<GeckoConfig>

CoinGecko configuration

defillama: Option<LlamaConfig>

DefiLlama configuration

moralis: Option<MoralisConfig>

Moralis configuration

dune: Option<DuneConfig>

Dune configuration

dune_sim: Option<DuneSimConfig>

Dune SIM configuration (separate from Dune Analytics)

chainlink: Option<ChainlinkConfig>

Chainlink Data Streams configuration

zerox: Option<ZeroxConfig>

0x API configuration

oneinch: Option<OneInchConfig>

1inch API configuration

enso: Option<EnsoConfig>

Enso Finance API configuration

thegraph: Option<TheGraphConfig>

The Graph API configuration (for Uniswap subgraphs)

solodit: Option<SoloditConfig>

Solodit API configuration

debug_rpc_urls: Vec<String>

Debug-capable RPC endpoints (for debug_traceCall, etc.)

Implementations

Source

impl ConfigFile

pub fn default_path() -> PathBuf

Get the default config file path

Can be overridden by setting the ETHCLI_CONFIG_DIR environment variable.

pub fn load_default() -> Result<Option<Self>>

Load from default path

pub fn load(path: &Path) -> Result<Self>

Load from a specific path

MED-003 fix: Uses shared file lock to coordinate with concurrent writers.

pub fn save(&self, path: &Path) -> Result<()>

Save to a specific path

MED-003/HIGH-001 fix: Uses file-level locking with atomic write pattern to prevent TOCTOU race conditions and data loss when multiple CLI instances run simultaneously.

Uses write-to-temp-and-rename pattern for atomic writes:

  1. Write to a unique temporary file with exclusive lock
  2. Set restrictive permissions (before rename to avoid race)
  3. Sync to disk
  4. Rename atomically to target path
pub fn save_default(&self) -> Result<()>

Save to default path

pub fn is_endpoint_disabled(&self, url: &str) -> bool

Check if an endpoint URL is disabled

pub fn proxy_config(&self) -> Option<ProxyConfig>

Convert proxy config to runtime ProxyConfig

pub fn proxy_for_source(&self, source: &str) -> Option<String>

Get proxy URL for a specific source (respects enabled, sources, exclude_sources)

pub fn set_etherscan_key(&mut self, key: String) -> Result<()>

Set the Etherscan API key and save

pub fn set_tenderly( &mut self, access_key: String, account: String, project: String, ) -> Result<()>

Set Tenderly credentials and save

pub fn add_debug_rpc(&mut self, url: String) -> Result<()>

Add a debug RPC URL and save

pub fn remove_debug_rpc(&mut self, url: &str) -> Result<()>

Remove a debug RPC URL and save

pub fn update_endpoint_block_range( &mut self, url: &str, max_block_range: u64, ) -> Result<bool>

Update an endpoint’s max_block_range (runtime learning)

pub fn update_endpoint_max_logs( &mut self, url: &str, max_logs: usize, ) -> Result<bool>

Update an endpoint’s max_logs (runtime learning)

pub fn disable_endpoint(&mut self, url: &str) -> Result<bool>

Disable an endpoint (runtime learning - endpoint is broken)