#[non_exhaustive]pub enum Error {
Rpc(RpcError),
Abi(AbiError),
Config(ConfigError),
Output(OutputError),
Checkpoint(CheckpointError),
Io(Error),
Json(Error),
Other(String),
}Expand description
Main error type for the library
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Rpc(RpcError)
RPC-related errors
Abi(AbiError)
ABI-related errors
Config(ConfigError)
Configuration errors
Output(OutputError)
Output errors
Checkpoint(CheckpointError)
Checkpoint errors
Io(Error)
Generic IO error
Json(Error)
JSON serialization error
Other(String)
Generic error for cases that don’t fit other categories.
When using this variant, prefer including context about the operation
that failed, e.g., Error::Other(format!("Failed to parse address: {}", input))
rather than just passing through a raw error message.