pub struct ProxyRotator { /* private fields */ }Expand description
Proxy rotator for distributing requests across multiple proxies
Implementations
Sourceimpl ProxyRotator
impl ProxyRotator
Sourcepub fn new(proxies: Vec<String>, mode: RotationMode) -> Self
pub fn new(proxies: Vec<String>, mode: RotationMode) -> Self
Create a new proxy rotator from a list of URLs
Sourcepub fn from_file(path: &Path, mode: RotationMode) -> Result<Self>
pub fn from_file(path: &Path, mode: RotationMode) -> Result<Self>
Create from a proxy file (one URL per line)
HIGH-002 fix: Validates and canonicalizes the path before reading to:
- Resolve symlinks to their actual target
- Normalize path traversal sequences (../)
- Provide a clear error if the file doesn’t exist
Sourcepub fn mark_failed(&self)
pub fn mark_failed(&self)
Mark current proxy as failed and move to next