Module selector

Module selector 

Smart RPC endpoint selection

Provides intelligent endpoint selection based on:

  • Priority (higher priority endpoints preferred)
  • Random distribution among same-priority endpoints (load balancing)
  • Chain filtering
  • Archive node filtering for historical queries

Structs

SelectionOptions
Options for endpoint selection

Functions

get_archive_endpoint
Get an RPC endpoint that is guaranteed to be an archive node
get_rpc_endpoint
Get an RPC endpoint with smart selection
get_rpc_endpoint_for_block
Get an RPC endpoint with archive node preference for historical queries
get_rpc_endpoint_from_config
Get an RPC endpoint from a pre-loaded config
get_rpc_endpoint_from_config_with_options
Get an RPC endpoint from a pre-loaded config with selection options
get_rpc_url
Get the URL of a smart-selected RPC endpoint
get_rpc_url_for_block
Get an RPC URL for a historical block query
get_rpc_url_from_config
Get an RPC URL from a pre-loaded config