urlencoding_encode

Function urlencoding_encode 

pub fn urlencoding_encode(input: &str) -> Cow<'_, str>
URL-encode a string for safe use in query parameters Only encodes characters that are unsafe in URLs