Aggregation layer for combining data from multiple API sources
This module provides:
- Core aggregation types (
SourceResult,AggregatedResult) - Data normalization types (
NormalizedPrice,NormalizedBalance,NormalizedNft) - Price aggregation from multiple sources
- Chain name normalization across services
Re-exports
pub use chain_map::*;pub use nft::*;pub use normalize::*;pub use portfolio::*;pub use price::*;pub use swap::*;pub use yields::*;
Modules
- chain_
map - Chain name normalization across different API services
- nft
- NFT aggregation from multiple sources
- normalize
- Data normalization types for aggregating responses from different API sources
- portfolio
- Portfolio aggregation from multiple API sources
- price
- Price aggregation from multiple API sources
- swap
- Swap quote aggregation from multiple DEX aggregator sources
- yields
- Yield aggregation from Curve and DefiLlama
Structs
- Aggregated
Result - Aggregated result from multiple sources
- Latency
Measure - Helper to measure async operation latency
- Source
Result - Result from a single API source
Enums
- Price
Source - Price source enum for CLI selection and aggregation
Functions
- get_
cached_ config - Get the cached config file, loading it once if needed.