Smart RPC endpoint selection
Provides intelligent endpoint selection based on:
- Priority (higher priority endpoints preferred)
- Random distribution among same-priority endpoints (load balancing)
- Chain filtering
- Archive node filtering for historical queries
Structs
- Selection
Options - Options for endpoint selection
Functions
- get_
archive_ endpoint - Get an RPC endpoint that is guaranteed to be an archive node
- get_
rpc_ endpoint - Get an RPC endpoint with smart selection
- get_
rpc_ endpoint_ for_ block - Get an RPC endpoint with archive node preference for historical queries
- get_
rpc_ endpoint_ from_ config - Get an RPC endpoint from a pre-loaded config
- get_
rpc_ endpoint_ from_ config_ with_ options - Get an RPC endpoint from a pre-loaded config with selection options
- get_
rpc_ url - Get the URL of a smart-selected RPC endpoint
- get_
rpc_ url_ for_ block - Get an RPC URL for a historical block query
- get_
rpc_ url_ from_ config - Get an RPC URL from a pre-loaded config